#version 150

uniform sampler2D DiffuseSampler;
uniform sampler2D DiffuseDepthSampler;

in vec2 texCoord;
in vec2 oneTexel;

uniform vec2 InSize;

uniform vec2 BlurDir;
uniform float Radius;

out vec4 fragColor;
float near = 0.01; 
float far  = 1;
float LinearizeDepth(float depth) 
{
    float z = depth * 2.0 - 1.0;
    return (near * far) / (far + near - z * (far - near));    
}

void main() {
    float depth = LinearizeDepth(texture2D(DiffuseDepthSampler,texCoord).r);
    float ldepth = LinearizeDepth(texture2D(DiffuseDepthSampler,vec2(0.5,0.5)).r);
    float d = abs(depth-ldepth);
    float dist = clamp(distance(texCoord,vec2(0.5,0.5))*4,0.,1.);
    vec2 b = vec2(clamp(BlurDir.x*d,0.0,1.0),clamp(BlurDir.y*d,0.0,1.0));
    vec4 blurred = vec4(0.0);
    float totalStrength = 0.0;
    float totalAlpha = 0.0;
    float totalSamples = 0.0;
    vec4 dif = texture(DiffuseSampler, texCoord);
    for(float r = -Radius; r <= Radius; r += 1.0) {
        vec4 sampleValue = texture(DiffuseSampler, texCoord + oneTexel * r * b);

		// Accumulate average alpha
        totalAlpha = totalAlpha + sampleValue.a;
        totalSamples = totalSamples + 1.0;

		// Accumulate smoothed blur
        float strength = 1.0 - abs(r / Radius);
        totalStrength = totalStrength + strength;
        blurred = blurred + sampleValue;
    }
    fragColor = vec4(mix(dif.rgb,blurred.rgb / (Radius * 2.0 + 1.0),vec3(dist,dist,dist)), totalAlpha);
}
